# -*-  coding: utf-8 -*-
# Copyright (C) 2015 ZetaOps Inc.
#
# This file is licensed under the GNU General Public License v3
# (GPLv3).  See LICENSE.txt for details.
""" Personel Modülü

Bu modül Ulakbüs uygulaması için personel modelini ve  personel ile ilişkili modelleri içerir.

"""
from .hitap.hitap_sebep import HitapSebep
from pyoko.lib.utils import lazy_property

from pyoko import Model, field
from ulakbus.lib.personel import gorunen_kademe_hesapla
from .auth import Unit, User
from ulakbus.settings import SICIL_PREFIX


class Personel(Model):
    """Personel Modeli

    Personelin özlük ve iletişim bilgilerini içerir.

    """

    tckn = field.String("TC No")
    kurum_sicil_no_int = field.Integer("Kurum Sicil No")
    ad = field.String("Adı")
    soyad = field.String("Soyadı")
    cinsiyet = field.Integer("Cinsiyet", choices='cinsiyet')
    uyruk = field.String("Uyruk")
    ikamet_adresi = field.String("İkamet Adresi")
    ikamet_il = field.String("İkamet İl")
    ikamet_ilce = field.String("İkamet İlçe")
    adres_2 = field.String("Adres 2")
    oda_no = field.String("Oda Numarası")
    oda_tel_no = field.String("Oda Telefon Numarası")
    cep_telefonu = field.String("Cep Telefonu")
    e_posta = field.String("E-Posta")
    e_posta_2 = field.String("E-Posta 2")
    e_posta_3 = field.String("E-Posta 3")
    web_sitesi = field.String("Web Sitesi")
    yayinlar = field.String("Yayınlar")
    projeler = field.String("Projeler")
    kan_grubu = field.String("Kan Grubu")
    ehliyet = field.String("Ehliyet")
    verdigi_dersler = field.String("Verdiği Dersler")
    biyografi = field.Text("Biyografi")
    notlar = field.Text("Notlar")
    engelli_durumu = field.String("Engellilik")
    engel_grubu = field.String("Engel Grubu")
    engel_derecesi = field.String("Engel Derecesi")
    engel_orani = field.Integer("Engellilik Oranı")
    cuzdan_seri = field.String("Seri")
    cuzdan_seri_no = field.String("Seri No")
    baba_adi = field.String("Ana Adı")
    ana_adi = field.String("Baba Adı")
    dogum_tarihi = field.Date("Doğum Tarihi", format="%d.%m.%Y")
    dogum_yeri = field.String("Doğum Yeri")
    medeni_hali = field.Integer("Medeni Hali", choices="medeni_hali")
    kayitli_oldugu_il = field.String("İl")
    kayitli_oldugu_ilce = field.String("İlçe")
    kayitli_oldugu_mahalle_koy = field.String("Mahalle/Köy")
    kayitli_oldugu_cilt_no = field.String("Cilt No")
    kayitli_oldugu_aile_sira_no = field.String("Aile Sıra No")
    kayitli_oldugu_sira_no = field.String("Sıra No")
    kimlik_cuzdani_verildigi_yer = field.String("Cüzdanın Verildiği Yer")
    kimlik_cuzdani_verilis_nedeni = field.String("Cüzdanın Veriliş Nedeni")
    kimlik_cuzdani_kayit_no = field.String("Cüzdan Kayıt No")
    kimlik_cuzdani_verilis_tarihi = field.String("Cüzdan Kayıt Tarihi")

    kazanilmis_hak_derece = field.Integer("Güncel Kazanılmış Hak Derece", index=True)
    kazanilmis_hak_kademe = field.Integer("Güncel Kazanılmış Hak Kademe", index=True)
    kazanilmis_hak_ekgosterge = field.Integer("Kazanılmış Hak Ek Gösterge", index=True)

    gorev_ayligi_derece = field.Integer("Güncel Görev Aylığı Derece", index=True)
    gorev_ayligi_kademe = field.Integer("Güncel Görev Aylığı Kademe", index=True)
    gorev_ayligi_ekgosterge = field.Integer("Görev Aylığı Ek Gösterge", index=True)

    emekli_muktesebat_derece = field.Integer("Güncel Emekli Müktesebat Derece", index=True)
    emekli_muktesebat_kademe = field.Integer("Güncel Emekli Müktesebat Kademe", index=True)
    emekli_muktesebat_ekgosterge = field.Integer("Emekli Müktesebat Ek Gösterge", index=True)

    kh_sonraki_terfi_tarihi = field.Date("Kazanılmış Hak Sonraki Terfi Tarihi", index=True,
                                         format="%d.%m.%Y")
    ga_sonraki_terfi_tarihi = field.Date("Görev Aylığı Sonraki Terfi Tarihi", index=True,
                                         format="%d.%m.%Y")
    em_sonraki_terfi_tarihi = field.Date("Emekli Müktesebat Sonraki Terfi Tarihi", index=True,
                                         format="%d.%m.%Y")

    birim = Unit("Birim")

    # Personelin Kendi Ünvanı
    unvan = field.Integer("Personel Unvan", index=True, choices="unvan_kod", required=False)

    # Aşağıdaki bilgiler atama öncesi kontrol edilecek, Doldurulması istenecek
    emekli_sicil_no = field.String("Emekli Sicil No", index=True)
    emekli_giris_tarihi = field.Date("Emekliliğe Giriş Tarihi", index=True, format="%d.%m.%Y")

    personel_turu = field.Integer("Personel Türü", choices="personel_turu")
    hizmet_sinifi = field.Integer("Hizmet Sınıfı", choices="hizmet_sinifi")
    statu = field.Integer("Statü", choices="personel_statu")
    brans = field.String("Branş", index=True)

    # akademik personeller icin sozlesme sureleri
    gorev_suresi_baslama = field.Date("Görev Süresi Başlama", index=True, format="%d.%m.%Y")
    gorev_suresi_bitis = field.Date("Görev Süresi Bitiş", index=True, format="%d.%m.%Y")

    # todo: durum_degisikligi yonetimi
    # kurumda ilk goreve baslama bilgileri, atama modelinden elde edilip
    # edilemeyecegini soracagiz. mevcut otomasyonda ayrilmalar da burada tutuluyor.
    # bunu tarih ve durum_degisikligi fieldlarindan olusan bir listnode seklinde tutabiliriz.
    goreve_baslama_tarihi = field.Date("Göreve Başlama Tarihi", index=True, format="%d.%m.%Y")
    baslama_sebep = HitapSebep()
    baslama_sebep.title = "Durum"

    # aday ve idari memurlar icin mecburi hizmet suresi
    mecburi_hizmet_suresi = field.Date("Mecburi Hizmet Süresi", index=True, format="%d.%m.%Y")

    # Arama için kullanılacak Flaglar
    kadro_derece = field.Integer(default=0)
    aday_memur = field.Boolean()
    arsiv = field.Boolean()  # ayrilmis personeller icin gecerlidir.

    user = User(one_to_one=True)

    class Meta:
        app = 'Personel'
        verbose_name = "Personel"
        verbose_name_plural = "Personeller"
        list_fields = ['ad', 'soyad', 'tckn', 'durum']
        search_fields = ['ad', 'soyad', 'cep_telefonu', 'tckn']

    def durum(self):
        return self.nufus_kayitlari.durum if self.nufus_kayitlari.key else None

    durum.title = "Durum"

    @lazy_property
    def gorunen_kazanilmis_hak_kademe(self):
        return gorunen_kademe_hesapla(int(self.kazanilmis_hak_derece),
                                      int(self.kazanilmis_hak_kademe))

    @lazy_property
    def gorunen_gorev_ayligi_kademe(self):
        return gorunen_kademe_hesapla(int(self.gorev_ayligi_derece), int(self.gorev_ayligi_kademe))

    @lazy_property
    def gorunen_emekli_muktesebat_kademe(self):
        return gorunen_kademe_hesapla(int(self.emekli_muktesebat_derece),
                                      int(self.emekli_muktesebat_kademe))

    @lazy_property
    def atama(self):
        """atama

        Personelin atama bilgilerini iceren atama nesnesini getirir.

        Returns:
            Atama örneği (instance)

        """
        # Mevcut pyoko API'i ile uyumlu olmasi icin, geriye bos bir Atama nesnesi dondurur.
        atamalar = Atama.objects.set_params(sort='goreve_baslama_tarihi desc').filter(personel=self)
        return atamalar[0] if atamalar else Atama()

    @lazy_property
    def kadro(self):
        """Kadro

        Personelin atama bilgilerinden kadrosuna erişir.

        Returns:
            Kadro örneği (instance)

        """

        return self.atama.kadro

    @lazy_property
    def sicil_no(self):
        """Kadro

        Personelin atama bilgilerinden sicil numarasina erişir.

        Returns:
            Sicil No (str)

        """

        return self.atama.kurum_sicil_no

    @property
    def kurum_sicil_no(self):
        return "%s-%s" % (SICIL_PREFIX, self.kurum_sicil_no_int)

    def __unicode__(self):
        return "%s %s" % (self.ad, self.soyad)


class AdresBilgileri(Model):
    """Adres Bilgileri Modeli

    Personele ait adres bilgilerini içeren modeldir.

    Personelin birden fazla adresi olabilir.

    """

    ad = field.String("Adres Adı")
    adres = field.String("Adres")
    ilce = field.String("İlçe")
    il = field.String("İl")
    personel = Personel()

    class Meta:
        verbose_name = "Adres Bilgisi"
        verbose_name_plural = "Adres Bilgileri"

    def __unicode__(self):
        return "%s %s" % (self.ad, self.il)


class KurumIciGorevlendirmeBilgileri(Model):
    """Kurum İçi Görevlendirme Bilgileri Modeli

    Personelin, kurum içi görevlendirme bilgilerine ait modeldir.

    Görevlendirme bir birim ile ilişkili olmalıdır.

    """

    gorev_tipi = field.String("Görev Tipi", choices="gorev_tipi")
    kurum_ici_gorev_baslama_tarihi = field.Date("Başlama Tarihi", format="%d.%m.%Y")
    kurum_ici_gorev_bitis_tarihi = field.Date("Bitiş Tarihi", format="%d.%m.%Y")
    birim = Unit()
    aciklama = field.String("Açıklama")
    resmi_yazi_sayi = field.String("Resmi Yazı Sayı")
    resmi_yazi_tarih = field.Date("Resmi Yazı Tarihi", format="%d.%m.%Y")
    personel = Personel()

    class Meta:
        """``form_grouping`` kullanıcı arayüzeyinde formun temel yerleşim planını belirler.

        Layout grid (toplam 12 sütun) içerisindeki değerdir.

        Her bir ``layout`` içinde birden fazla form grubu yer alabilir: ``groups``

        Her bir grup, grup başlığı ``group_title``, form öğeleri ``items`` ve bu grubun
        açılır kapanır olup olmadığını belirten boolen bir değerden ``collapse`` oluşur.

        """

        verbose_name = "Kurum İçi Görevlendirme"
        verbose_name_plural = "Kurum İçi Görevlendirmeler"
        form_grouping = [
            {
                "layout": "4",
                "groups": [
                    {
                        "group_title": "Gorev",
                        "items": ["gorev_tipi", "kurum_ici_gorev_baslama_tarihi",
                                  "kurum_ici_gorev_bitis_tarihi",
                                  "birim", "aciklama"],
                        "collapse": False
                    }
                ]

            },
            {
                "layout": "2",
                "groups": [
                    {
                        "group_title": "Resmi Yazi",
                        "items": ["resmi_yazi_sayi", "resmi_yazi_tarih"],
                        "collapse": False
                    }
                ]

            },
        ]

    def __unicode__(self):
        return "%s %s" % (self.gorev_tipi, self.aciklama)


class KurumDisiGorevlendirmeBilgileri(Model):
    """Kurum Dışı Görevlendirme Bilgileri Modeli

    Personelin bağlı olduğu kurumun dışındaki görev bilgilerine ait modeldir.

    """

    gorev_tipi = field.Integer("Görev Tipi")
    kurum_disi_gorev_baslama_tarihi = field.Date("Başlama Tarihi", format="%d.%m.%Y")
    kurum_disi_gorev_bitis_tarihi = field.Date("Bitiş Tarihi", format="%d.%m.%Y")
    aciklama = field.Text("Açıklama")
    resmi_yazi_sayi = field.String("Resmi Yazı Sayı")
    resmi_yazi_tarih = field.Date("Resmi Yazı Tarihi", format="%d.%m.%Y")
    maas = field.Boolean("Maaş")
    yevmiye = field.Boolean("Yevmiye", default=False)
    yolluk = field.Boolean("Yolluk", default=False)
    ulke = field.Integer("Ülke", default="90", choices="ulke")
    personel = Personel()

    class Meta:
        verbose_name = "Kurum Dışı Görevlendirme"
        verbose_name_plural = "Kurum Dışı Görevlendirmeler"
        list_fields = ["ulke", "gorev_tipi", "kurum_disi_gorev_baslama_tarihi"]
        list_filters = ["ulke", "gorev_tipi", "kurum_disi_gorev_baslama_tarihi"]
        search_fields = ["aciklama", ]
        form_grouping = [
            {
                "layout": "4",
                "groups": [
                    {
                        "group_title": "Gorev",
                        "items": ["gorev_tipi", "kurum_disi_gorev_baslama_tarihi",
                                  "kurum_disi_gorev_bitis_tarihi",
                                  "ulke",
                                  "aciklama"],
                        "collapse": False
                    }
                ]

            },
            {
                "layout": "2",
                "groups": [
                    {
                        "group_title": "Resmi Yazi",
                        "items": ["resmi_yazi_sayi", "resmi_yazi_tarih"],
                        "collapse": False
                    },
                    {
                        "items": ["maas", "yevmiye", "yolluk"],
                        "collapse": False
                    }
                ]

            },
        ]

    def __unicode__(self):
        return "%s %s %s" % (self.gorev_tipi, self.aciklama, self.ulke)


class Kadro(Model):
    """Kadro Modeli

    Kurum için ayrılmış Kadro bilgilerine modeldir.

    Kadrolar 4 halde bulunabilirler: SAKLI, IZINLI, DOLU ve BOŞ

        * SAKLI: Saklı kadro, atama yapılmaya müsadesi olmayan, etkinlik onayı alınmamış
          fakat kurum için ayrılmış potansiyel kadroyu tanımlar.
        * IZINLI: Henüz atama yapılmamış, fakat etkinlik onayı alınmış kadroyu tanımlar.
        * DOLU: Bir personel tarafından işgal edilmiş bir kadroyu tanımlar. Ataması yapılmıştır.
        * BOŞ: Çeşitli sebepler ile DOLU iken boşaltılmış kadroyu tanınmlar.

    ``unvan`` ve ``unvan_kod`` karşıt alanlardır. Birisi varken diğeri mevcut olamaz.

    """

    kadro_no = field.Integer("Kadro No", required=False)
    derece = field.Integer("Derece", required=False)
    durum = field.Integer("Durum", choices="kadro_durumlari", required=False)
    birim = Unit("Birim", required=False)
    aciklama = field.String("Açıklama", index=True, required=False)
    unvan = field.Integer("Unvan", index=True, choices="unvan_kod", required=False)
    unvan_aciklama = field.String("Unvan Aciklama", index=True, required=False)

    class Meta:
        app = 'Personel'
        verbose_name = "Kadro"
        verbose_name_plural = "Kadrolar"
        list_fields = ['durum', 'unvan', 'aciklama']
        search_fields = ['unvan', 'derece']
        list_filters = ['durum']

    def __unicode__(self):
        return "%s - %s %s. derece" % (self.kadro_no, self.get_unvan_display(), self.derece)


class Izin(Model):
    """İzin Modeli

    Personelin ücretli izin bilgilerini içeren modeldir.

    """

    tip = field.Integer("Tip", choices="izin")
    baslangic = field.Date("Başlangıç", format="%d.%m.%Y")
    bitis = field.Date("Bitiş", format="%d.%m.%Y")
    onay = field.Date("Onay", format="%d.%m.%Y")
    adres = field.String("Geçireği Adres")
    telefon = field.String("Telefon")
    personel = Personel()
    vekil = Personel()

    class Meta:
        app = 'Personel'
        verbose_name = "İzin"
        verbose_name_plural = "İzinler"
        list_fields = ['tip', 'baslangic', 'bitis', 'onay', 'telefon']
        search_fields = ['tip', 'baslangic', 'onay']

    def __unicode__(self):
        return '%s %s' % (self.tip, self.onay)


class UcretsizIzin(Model):
    """Ücretsiz izin Modeli

    Personelin ücretsiz izin bilgilerini içeren modeldir.

    """

    tip = field.Integer("Tip", choices="ucretsiz_izin")
    baslangic_tarihi = field.Date("İzin Başlangıç Tarihi", format="%d.%m.%Y")
    bitis_tarihi = field.Date("İzin Bitiş Tarihi", format="%d.%m.%Y")
    donus_tarihi = field.Date("Dönüş Tarihi", format="%d.%m.%Y")
    donus_tip = field.Integer("Dönüş Tip")
    onay_tarihi = field.Date("Onay Tarihi", format="%d.%m.%Y")
    personel = Personel()

    class Meta:
        app = 'Personel'
        verbose_name = "Ücretsiz İzin"
        verbose_name_plural = "Ücretsiz İzinler"
        list_fields = ['tip', 'baslangic_tarihi', 'bitis_tarihi', 'donus_tarihi']
        search_fields = ['tip', 'onay_tarihi']

    def __unicode__(self):
        return '%s %s' % (self.tip, self.onay_tarihi)


class Atama(Model):
    """Atama Modeli

    Personelin atama bilgilerini içeren modeldir.

    """

    ibraz_tarihi = field.Date("İbraz Tarihi", index=True, format="%d.%m.%Y")
    durum = HitapSebep()
    durum.title = "Durum"
    nereden = field.Integer("Nereden", index=True)  # modele baglanacak.
    atama_aciklama = field.String("Atama Açıklama", index=True)
    goreve_baslama_tarihi = field.Date("Göreve Başlama Tarihi", index=True, format="%d.%m.%Y")
    goreve_baslama_aciklama = field.String("Göreve Başlama Açıklama", index=True)
    kadro = Kadro()
    personel = Personel()
    # Arama için eklendi, Orjinali personelde tutulacak
    hizmet_sinifi = field.Integer("Hizmet Sınıfı", index=True, choices="hizmet_sinifi")

    class Meta:
        app = 'Personel'
        verbose_name = "Atama"
        verbose_name_plural = "Atamalar"
        list_fields = ['hizmet_sinif', 'gorev_suresi_baslama', 'ibraz_tarihi',
                       'durum']
        search_fields = ['hizmet_sinif', 'statu']

    def __unicode__(self):
        return '%s %s %s' % (self.personel.kurum_sicil_no,
                             self.gorev_suresi_baslama, self.ibraz_tarihi)

    @classmethod
    def personel_guncel_atama(cls, personel):
        """
        Personelin goreve_baslama_tarihi ne göre son atama kaydını döndürür.

        Returns:
            Atama örneği (instance)

        """

        return cls.objects.set_params(
            sort='goreve_baslama_tarihi desc').filter(personel=personel)[0]

    @classmethod
    def personel_ilk_atama(cls, personel):
        """
        Personelin goreve_baslama_tarihi ne göre ilk atama kaydını döndürür.

        Returns:
            Atama örneği (instance)

        """

        return cls.objects.set_params(
            sort='goreve_baslama_tarihi asc').filter(personel=personel)[0]

    def post_save(self):
        # Personel modeline arama için eklenen kadro_derece set edilecek
        self.personel.kadro_derece = self.kadro.derece
        self.personel.save()

        # Atama sonrası kadro dolu durumuna çekilecek
        self.kadro.durum = 4
        self.kadro.save()

    def pre_save(self):
        self.hizmet_sinifi = self.personel.hizmet_sinifi
        # Atama kaydetmeden önce kadro boş durumuna çekilecek
        self.kadro.durum = 2
        self.kadro.save()

    def post_delete(self):
        # Atama silinirse kadro boş duşuma çekilecek
        self.kadro.durum = 2
        self.kadro.save()

        # personelin kadro derecesi 0 olacak
        self.personel.kadro_derece = 0
        self.personel.save()



# -*-  coding: utf-8 -*-
"""project settings"""

# Copyright (C) 2015 ZetaOps Inc.
#
# This file is licensed under the GNU General Public License v3
# (GPLv3).  See LICENSE.txt for details.
from zengine.settings import *
import os.path

__author__ = 'Evren Esat Ozkan'

BASE_DIR = os.path.dirname(os.path.realpath(__file__))

DEFAULT_LANG = 'tr'

# path of the activity modules which will be invoked by workflow tasks
ACTIVITY_MODULES_IMPORT_PATHS.extend(['ulakbus.views', 'ulakbus.tasks'])
# absolute path to the workflow packages
WORKFLOW_PACKAGES_PATHS.append(os.path.join(BASE_DIR, 'diagrams'))

LOG_FILE = os.environ.get('LOG_FILE', './ulakbus.log')

AUTH_BACKEND = 'ulakbus.models.auth.AuthBackend'

PERMISSION_MODEL = 'ulakbus.models.auth.Permission'
USER_MODEL = 'ulakbus.models.auth.User'
ROLE_MODEL = 'ulakbus.models.auth.Role'
# # left blank to use StreamHandler aka stderr
# LOG_HANDLER = os.environ.get('LOG_HANDLER', 'file')
#
# # logging dir for file handler
# LOG_DIR = os.environ.get('LOG_DIR', '/tmp/')

# DEFAULT_CACHE_EXPIRE_TIME = 99999999  # seconds

# diagrams that does not require logged in user
ANONYMOUS_WORKFLOWS.extend(['login', 'logout'])

# #PYOKO SETTINGS
DEFAULT_BUCKET_TYPE = os.environ.get('DEFAULT_BUCKET_TYPE', 'models')

DATE_DEFAULT_FORMAT = "%d.%m.%Y"
DATETIME_DEFAULT_FORMAT = "%d.%m.%Y %H:%S"

DEFAULT_WF_CATEGORY_NAME = 'Genel'
DEFAULT_OBJECT_CATEGORY_NAME = 'Seçime Uygun Görevler'

OBJECT_MENU = {
    # 'personel|ogrenci|personeller|ogrenciler': [{'name':'ModelName',
    #                                             'field':'field_name',
    #                                             'verbose_name': 'verbose_name',
    #                                             'category': 'Genel'
    #                                             'wf':'crud'}]
    # 'field' defaults to 'personel' or 'ogrenci'
    # verbose_name can be specified to override the model's verbose_name_plural
    'other': [
        {'name': 'Personel', 'category': 'Genel'},
        {'name': 'Ogrenci', 'category': 'Genel'},
        {'name': 'Okutman', 'category': 'Genel'},
        {'name': 'HariciOkutman', 'category': 'Genel'},
        {'name': 'Donem', 'category': 'Genel'},
        {'name': 'Program', 'category': 'Genel'},
        {'name': 'Ders', 'category': 'Genel'},
        {'name': 'Campus', 'category': 'Genel'},
        {'name': 'Building', 'category': 'Genel'},
        {'name': 'Room', 'category': 'Genel'},
        {'name': 'AkademikTakvim', 'category': 'Genel'},
        {'name': 'OgrenciProgram', 'category': 'Genel'},
    ],
    'personel': [
        {'name': 'Personel', 'wf': 'kimlik_ve_iletisim_bilgileri',
         'verbose_name': 'Kimlik ve Iletisim Bilgileri', 'field': 'personel_id'},

        {'name': 'Izin', 'wf': 'izin', 'verbose_name': 'İzin İşlemleri', 'field': 'personel_id'},

        {'name': 'UcretsizIzin', 'wf': 'ucretsiz_izin', 'verbose_name': 'Ücretsiz İzin İşlemleri',
         'field': 'personel_id'},

        {'name': 'KurumDisiGorevlendirmeBilgileri', 'field': 'personel_id'},

        {'name': 'KurumIciGorevlendirmeBilgileri', 'field': 'personel_id'},

        {'name': 'AdresBilgileri', 'verbose_name': 'Adres Bilgileri', 'field': 'personel_id'},

        {'name': 'Atama', 'verbose_name': 'Atama İşlemleri', "wf": 'personel_atama',
         'field': 'personel_id'},

        {'name': 'Izin', 'verbose_name': 'İzin Başvuru', 'wf': 'izin_basvuru',
         'field': 'personel_id'},

        {'name': 'Personel', 'verbose_name': 'Akademik Personel Görev Süresi Uzatma',
         'wf': 'gorev_suresi_uzatma', 'field': 'personel_id'},

        # Hitap İşlemleri
        {'name': 'HizmetKayitlari', 'verbose_name': 'Hizmet Cetveli', 'field': 'personel_id',
         'category': 'Hitap İşlemleri', 'wf': 'personel_hizmet_cetveli'},

        {'name': 'HizmetKurs', 'verbose_name': 'Kurs Bilgileri', 'field': 'personel_id',
         'category': 'Hitap İşlemleri', 'wf': 'crud_hitap'},

        {'name': 'HizmetOkul', 'verbose_name': 'Okul Bilgileri', 'field': 'personel_id',
         'category': 'Hitap İşlemleri', 'wf': 'crud_hitap'},

        {'name': 'HizmetMahkeme', 'verbose_name': 'Mahkeme Bilgileri', 'field': 'personel_id',
         'category': 'Hitap İşlemleri', 'wf': 'crud_hitap'},

        {'name': 'HizmetBirlestirme', 'verbose_name': 'Hizmet Birleştirme', 'field': 'personel_id',
         'category': 'Hitap İşlemleri', 'wf': 'crud_hitap'},

        {'name': 'HizmetTazminat', 'verbose_name': 'Tazminat Bilgileri', 'field': 'personel_id',
         'category': 'Hitap İşlemleri', 'wf': 'crud_hitap'},

        {'name': 'HizmetUnvan', 'verbose_name': 'Ünvan', 'field': 'personel_id',
         'category': 'Hitap İşlemleri', 'wf': 'crud_hitap'},

        {'name': 'HizmetAcikSure', 'verbose_name': 'Açık Süre Bilgileri', 'field': 'personel_id',
         'category': 'Hitap İşlemleri', 'wf': 'crud_hitap'},

        {'name': 'HizmetBorclanma', 'verbose_name': 'Borçlanma Bilgileri', 'field': 'personel_id',
         'category': 'Hitap İşlemleri', 'wf': 'crud_hitap'},

        {'name': 'HizmetIHS', 'verbose_name': 'İtibari Hizmet', 'field': 'personel_id',
         'category': 'Hitap İşlemleri', 'wf': 'crud_hitap'},

        {'name': 'HizmetIstisnaiIlgi', 'verbose_name': 'İstisnai İlgi', 'field': 'personel_id',
         'category': 'Hitap İşlemleri', 'wf': 'crud_hitap'},

        {'name': 'AskerlikKayitlari', 'verbose_name': 'Askerlik Kayıtları', 'field': 'personel_id',
         'category': 'Hitap İşlemleri', 'wf': 'crud_hitap'},
    ],
    'ogrenci': [
        {'name': 'Borc', 'verbose_name': 'Harç Bilgileri', 'field': 'ogrenci_id'},
        {'name': 'OgrenciProgram', 'verbose_name': 'Öğrenci Mezuniyet', 'wf': 'ogrenci_mezuniyet',
         'field': 'ogrenci_id'},
        {'name': 'DegerlendirmeNot', 'field': 'ogrenci_id'},
        {'name': 'OgrenciDersi', 'field': 'ogrenci_id'},
        {'name': 'Ogrenci', 'field': 'object_id', 'wf': 'ogrenci_kimlik_bilgileri',
         'verbose_name': 'Kimlik Bilgileri'},
        {'name': 'Ogrenci', 'field': 'object_id', 'wf': 'ogrenci_iletisim_bilgileri',
         'verbose_name': 'İletişim Bilgileri'},
        {'name': 'OncekiEgitimBilgisi', 'verbose_name': 'Önceki Eğitim Bilgileri',
         'field': 'ogrenci_id'},
        # {'name': 'OgrenciProgram', 'field': 'ogrenci_id', 'wf': 'ders_ekle',
        #  'verbose_name': 'Ders Ekle'},
        {'name': 'OgrenciProgram', 'field': 'ogrenci_id', 'wf': 'danisman_atama',
         'verbose_name': 'Danışman Atama'},
        {'name': 'DondurulmusKayit', 'verbose_name': 'Kayıt Dondurma', 'wf': 'kayit_dondur',
         'field': 'ogrenci_id'},
        {'name': 'OgrenciProgram', 'verbose_name': 'Mazaretli Öğrenci',
         'wf': 'mazeretli_ders_kaydi', 'field': 'ogrenci_id'},
        {'name': 'DegerlendirmeNot', 'verbose_name': 'Not Düzenleme',
         'wf': 'ogrenci_isleri_not_duzenleme',
         'field': 'ogrenci_id'},
        {'name': 'OgrenciProgram', 'verbose_name': 'Kayıt Sil', 'wf': 'kayit_sil',
         'field': 'ogrenci_id'},
        {'name': 'OgrenciDersi', 'verbose_name': 'Ders Ekle', 'wf': 'ogrenci_ders_atama',
         'field': 'ogrenci_id'}
    ],
}

VIEW_URLS.update({
    # ('falcon URI template', 'python path to view method/class')
    'ogrenci_ara': 'ulakbus.views.system.SearchStudent',
    'personel_ara': 'ulakbus.views.system.SearchPerson',
    'notify': 'ulakbus.views.system.Notification',
    'get_current_user': 'ulakbus.views.system.GetCurrentUser',
    'dashboard': 'ulakbus.views.system.UlakbusMenu',
    'menu': 'ulakbus.views.system.UlakbusMenu',
    'ders_arama': 'ulakbus.views.ogrenci.ogrenci.ders_arama'
})

ZATO_SERVER = os.environ.get('ZATO_SERVER', 'http://localhost:11223')

ENABLE_SIMPLE_CRUD_MENU = False

ALLOWED_ORIGINS += [
    'http://ulakbus.net',
    'http://www.ulakbus.net',
    'http://dev.zetaops.io',
    'http://nightly.zetaops.io',
    'http://nightly.ulakbus.net'
]

UID = 173500

FILE_MANAGER = 'ulakbus.lib.s3_file_manager.S3FileManager'
ALLOWED_FILE_TYPES = {
    'png': ('image/png', 'png'),
    'txt': ('text/plain', 'txt'),
    'jpg': ('image/jpeg', 'jpg'),
    'jpeg': ('image/jpeg', 'jpg'),
    'pdf': ('application/pdf', 'pdf'),
    'doc': ('application/msword', 'doc'),
    'xls': ('application/vnd.ms-excel', 'xls'),
    'ppt': ('application/vnd.ms-powerpoint', 'ppt'),
    'pptx': ('application/vnd.openxmlformats-officedocument.presentationml.presentation', 'pptx'),
    'xlsx': ('application/vnd.openxmlformats-officedocument.spreadsheetml.sheet', 'xlsx'),
    'docx': ('application/vnd.openxmlformats-officedocument.wordprocessingml.document', 'docx'),
}

S3_PROXY_URL = os.environ.get('S3_PROXY_URL')
S3_ACCESS_KEY = os.environ.get('S3_ACCESS_KEY')
S3_SECRET_KEY = os.environ.get('S3_SECRET_KEY')
S3_PUBLIC_URL = os.environ.get('S3_PUBLIC_URL')
S3_PROXY_PORT = os.environ.get('S3_PROXY_PORT', '8080')
S3_BUCKET_NAME = 'ulakbus'

QUICK_MENU = [
    'kadro_islemleri',
    # 'izin',
    'akademik_takvim',
    'ders_hoca_sube_atama',
    'ders_ekle',
    'Birim',
    'Ders',
    'Program'
]

MAX_NUM_DROPDOWN_LINKED_MODELS = 20

PERMISSION_PROVIDER = 'ulakbus.models.auth.ulakbus_permissions'

ERROR_MESSAGE_500 = "DEMO Sisteminde güncelleme nedeniyle kesinti ve hata olabilir." \
                    "Şimdi bunlardan birini görüyorsunuz. Lütfen daha sonra tekrar deneyiniz"

SICIL_PREFIX = "KON"

#: These models will not flushed when running tests
TEST_FLUSHING_EXCLUDES = 'Unit,Permission,User,AbstractRole,Role'



# -*-  coding: utf-8 -*-
"""
"""

# Copyright (C) 2015 ZetaOps Inc.
#
# This file is licensed under the GNU General Public License v3
# (GPLv3).  See LICENSE.txt for details.

"""HITAP Sil Servisi

Hitap sil (delete) servislerinin kalıtılacağı
abstract HITAP Sil servisini içeren modül.


Attributes:
    H_USER (str): Hitap kullanıcı adı
    H_PASS (str): Hitap kullanıcı şifresi

"""
__author__ = 'H.İbrahim Yılmaz (drlinux)'

from zato.server.service import Service
from hitap_helper import HitapHelper
import os
import urllib2
from json import dumps
from six import iteritems

H_USER = os.environ["HITAP_USER"]
H_PASS = os.environ["HITAP_PASS"]


class HITAPSil(Service):
    """
    Hitap Silme servislerinin kalıtılacağı abstract Zato servisi.

    Silme servisleri gerekli girdileri (Hitap dict, Hitap username, Hitap password)
    Hitap'a yollayıp dönecek cevabı elde eder.

    Attributes:
        service_name (str): İlgili Hitap sorgu servisinin adı
        service_dict (dict): Hitap servisine yollanacak datayı hazırlamak için sözlük.
            Servise gönderilecek verinin alanlarına ait sözlüğü içerir.

    """

    def __init__(self):
        self.service_name = ''
        self.service_dict = {'fields': {'kayitNo': "", 'tckn': ""}}
        super(HITAPSil, self).__init__()

    def handle(self):
        """
        Servis çağrıldığında tetiklenen metod.

        Hitap'a gidecek isteği hazırlayacak ve gelen cevabı elde edecek olan
        request_json fonksiyonunu çağırır.

        """

        self.logger.info("zato service started to work.")
        conn = self.outgoing.soap['HITAP'].conn

        self.request_json(conn)

    def request_json(self, conn):
        """Connection bilgisi ve gerekli veriler ile Hitap'ın ilgili servisine
        istekte bulunup gelen cevabı uygun şekilde elde eder.

        Hitap'tan gelen verilerin sisteme uygun şekilde elde edilmesi için, gerekli
        Hitap sözlüğünü yaratan ve tarih alanı gibi belli alanlara uygun filteleri
        uygulayacak olan fonksiyonları çağırır.

        Veriler uygun şekilde elde edildikten sonra servis cevabı (payload) oluşturulur.

        Args:
            conn (zato.outgoing.soap.conn): Zato soap outgoing bağlantısı

        Raises:
            AttributeError: İlgili servis veya bean Hitap'ta bulunmayabilir.
            urllib2.URLError: Servis yanıt vermiyor.

        """

        status = "error"
        hitap_dict = []

        try:
            # connection for hitap
            with conn.client() as client:

                request_data = client.factory.create(self.service_name)

                request_data.kullaniciAd = H_USER
                request_data.sifre = H_PASS

                for dict_element in self.service_dict['fields']:
                    request_data[dict_element] = self.service_dict[dict_element]

                if 'required_fields' in self.service_dict:
                    required_field_check = HitapHelper()
                    required_field_check.check_required_data(self.service_dict)

                service_name = self.service_name
                hitap_service = getattr(client.service, self.service_name)(request_data)

            status = "ok"

        except AttributeError:
            self.logger.exception("AttributeError")
            status = "error"

        except urllib2.URLError:
            self.logger.exception("Service unavailable!")
            status = "error"

        finally:
            self.response.payload = {'status': status,
                                     'result': self.create_hitap_json(hitap_service)}

    def create_hitap_json(self, hitap_service):
        """Silme servisinden dönen veriyi JSON formatına döndürür.
        Converts SOAP call result object into JSON

        """
        dict_result = dict((name, getattr(hitap_service, name)) for name in dir(hitap_service)
                           if not name.startswith('__'))

        self.logger.info("hitap_service json created.")

        return dumps(dict_result)



# -*-  coding: utf-8 -*-
"""
"""

# Copyright (C) 2015 ZetaOps Inc.
#
# This file is licensed under the GNU General Public License v3
# (GPLv3).  See LICENSE.txt for details.
#
from zengine.forms import fields, JsonForm
from zengine.views.crud import CrudView, view_method, list_query
from ulakbus.models.personel import Personel


def zato_service_selector(model, action):
    """
    Model ve actionlara uygun Hitap Servislerini import eder.

    Args:
        model (class): model class object
        action (str): model uzerinde yapilacak eylem, sil, ekle, guncelle etc..

    Returns:
        hitap_service (class): Zato wrapperdan modulunden kritere uygun isi yapan class

    """

    suffix = {"add": "Ekle",
              "update": "Guncelle",
              "delete": "Sil",
              "get": "Getir",
              "sync": "SenkronizeEt"}[action]

    prefix = model.Meta.hitap_service_prefix
    service_class_name = prefix + suffix

    hitap_service = getattr(
        __import__('ulakbus.services.zato_wrapper', fromlist=[service_class_name]),
        service_class_name)

    return hitap_service


class ListFormHitap(JsonForm):
    """
    HITAP Sync eklenmis list view formu.
    """
    add = fields.Button("Ekle", cmd="add_edit_form")
    sync = fields.Button("HITAP ile senkronize et", cmd="sync")


class CrudHitap(CrudView):
    """CrudHitap İş Akışı

    CrudHitap, standart CrudView'a ait save, delete gibi metotların
    Hitap senkronizasyonunu ilgilendiren işlevsellikler ile
    genişletilerek elde edilmiştir.

    Bu iş akışı için senkronizasyon şu şekilde çalışmaktadır:

        - Yerel kayıtlarda yapılan her değişiklik anında Hitap
          ile eşlenecektir.

        - Silinen kayıtlar, ancak Hitap'tan silinme onayı geldikten
          sonra silinecektir. İlgili kayıt öncelikle ``silinecek``
          şeklinde işaretlenir. Hitap'tan silme işlemi ile ilgili olumlu
          sonuç geldikten sonra silinme işlemi gerçekleşir. Kayit
          senkronize olarak işaretlenir.

        - Yeni eklenen kayıtlar, gönderilecek şeklinde işaretlenir.
          Hitap'a gonderilir. Hitap'tan dönen kayıt no ile ilgili
          kayda eklenir ve senkronize şeklinde işaretlenir.

        - Güncellenen kayıtlar ise, güncelleniyor şeklinde işaretlenir.
          Guncellenen kayıt Hitap'a gönderilir. Hitap yeni bir kayıt no
          üretir ve eski kaydı siler. Bu işlem soncunda Hitap yeni bir
          ``kayıt no`` gönderir. Yereldeki kayıt yeni ``kayıt no`` ile
          güncellenir ve senkronize olarak işaretlenir.

    Buna gore ``sync`` field şu değerlerde bulunabilir:

        * 1: Kayıt Hitap ile senkronize
        * 2: Yerel kayıt güncellendi, Hitap güncellenecek
        * 3: Yerel kayıt silindi, Hitap kaydı silinecek
        * 4: Yeni bir yerel kayıt oluşturuldu, Hitap'a gönderilecek.

    """

    def __init__(self, current=None):
        super(CrudHitap, self).__init__(current)
        self.ListForm = ListFormHitap
        if 'id' in self.input:
            self.current.task_data['personel_id'] = self.input['id']
            self.current.task_data['personel_tckn'] = Personel.objects.get(self.input['id']).tckn

    @view_method
    def sync(self):
        """Crud Hitap Sync

        Personele ait kayitlari hitap ile sync eder. Zamanlanmis sync islemini
        manuel olarak calistirir.

        """
        hitap_service = zato_service_selector(self.model_class, 'sync')
        hs = hitap_service(tckn=str(self.current.task_data['personel_tckn']))
        hs.zato_request()

    def save(self):
        """Crud Hitap Kaydet

        Nesneyi kaydeder. Eğer kayıt yeni ise ``sync`` alanını 4,
        mevcut kayıt güncellemesi ise 2 olarak işaretler.

        Hemen ardından zato servisi ile değişikliği bildirir.

        """

        self.set_form_data_to_object()
        obj_is_new = not self.object.is_in_db()
        action, self.object.sync = ('add', 4) if obj_is_new else ('update', 2)
        self.object.save()

        hitap_service = zato_service_selector(self.model_class, action)
        hs = hitap_service(kayit=self.object)
        try:
            response = hs.zato_request()
            if response['status'] == 'ok':
                self.object.sync = 1
                self.object.save()
        except:
            # try blogundaki islemleri background gondermek
            pass

        if self.next_cmd and obj_is_new:
            self.current.task_data['added_obj'] = self.object.key

    def delete(self):
        """Crud Hitap Sil

        Nesneyi kaydeder. ``sync`` alanını 3 olarak işaretler.

        Hemen ardından zato servisi ile değişikliği bildirir.

        """

        self.current.task_data['deleted_obj'] = self.object.key
        if 'object_id' in self.current.task_data:
            del self.current.task_data['object_id']

        self.object.sync = 3
        hitap_service = zato_service_selector(self.model_class, 'delete')
        hs = hitap_service(kayit=self.object)

        try:
            response = hs.zato_request()
            if response['status'] == 'ok':
                self.object.sync = 1
                self.object.delete()
        except:
            # try blogundaki islemleri background gondermek
            pass

        self.set_client_cmd('reload')

    @list_query
    def list_by_personel_id(self, queryset):
        return queryset.filter(personel_id=self.current.task_data['personel_id'])



# -*-  coding: utf-8 -*-
"""
"""

# Copyright (C) 2015 ZetaOps Inc.
#
# This file is licensed under the GNU General Public License v3
# (GPLv3).  See LICENSE.txt for details.

"""HITAP Askerlik Ekle

Hitap'a personelin askerlik bilgilerinin eklenmesini yapar.

"""

__author__ = 'H.İbrahim Yılmaz (drlinux)'

from ulakbus.services.personel.hitap.hitap_ekle import HITAPEkle


class HizmetAskerlikEkle(HITAPEkle):
    """
    HITAP Ekleme servisinden kalıtılmış Hizmet Askerlik Bilgisi Ekleme servisi

    """

    def handle(self):
        """Servis çağrıldığında tetiklenen metod.

        Attributes:
            service_name (str): İlgili Hitap sorgu servisinin adı
            service_dict (dict): Request yoluyla gelen kayıtlar,
                    HizmetAskerlikInsert servisinin alanlarıyla eşlenmektedir.
                    Filtreden geçecek tarih alanları ve gerekli alanlar listede tutulmaktadır.
        """

        self.service_name = 'HizmetAskerlikInsert'
        self.service_dict = {
            'fields': {
                'askerlikNevi': self.request.payload.get('askerlik_nevi', ''),
                'baslamaTarihi': self.request.payload.get('baslama_tarihi', ''),
                'bitisTarihi': self.request.payload.get('bitis_tarihi', ''),
                'kitaBaslamaTarihi': self.request.payload.get('kita_baslama_tarihi', ''),
                'kitaBitisTarihi': self.request.payload.get('kita_bitis_tarihi', ''),
                'muafiyetNeden': self.request.payload.get('muafiyet_neden', ''),
                'sayilmayanGunSayisi': self.request.payload.get('sayilmayan_gun_sayisi', ''),
                'sinifOkuluSicil': self.request.payload.get('sinif_okulu_sicil', ''),
                'subayliktanErligeGecisTarihi': self.request.payload.get(
                    'subayliktan_erlige_gecis_tarihi', ''),
                'subayOkuluGirisTarihi': self.request.payload.get('subay_okulu_giris_tarihi', ''),
                'tckn': self.request.payload.get('tckn', ''),
                'tegmenNaspTarihi': self.request.payload.get('tegmen_nasp_tarihi', ''),
                'gorevYeri': self.request.payload.get('gorev_yeri', ''),
                'kurumOnayTarihi': self.request.payload.get('kurum_onay_tarihi', ''),
                'astegmenNaspTarihi': self.request.payload.get('astegmen_nasp_tarihi', '')
            },
            'date_filter': ['baslamaTarihi', 'bitisTarihi', 'kitaBaslamaTarihi', 'kitaBitisTarihi',
                            'subayliktanErligeGecisTarihi', 'subayOkuluGirisTarihi',
                            'tegmenNaspTarihi', 'kurumOnayTarihi', 'astegmenNaspTarihi'],
            'required_fields': ['tckn', 'askerlikNevi', 'kurumOnayTarihi']
        }
        super(HizmetAskerlikEkle, self).handle()



#!/usr/bin/env python
from distutils.core import setup

from setuptools import find_packages

setup(
    name='Ulakbus',
    version='0.8.4',
    description='Ulakbus Butunlesik Universite Sistemi',
    author='Zetaops',
    license='GPL v3',
    author_email='info@zetaops.io',
    install_requires=[
        'zengine==0.7.3',
        'requests',
        'boto',
        'reportlab',
        'six',
        'lxml'
    ],
    url='https://github.com/zetaops/ulakbus',
    packages=find_packages(exclude=['tests', 'tests.*']),
    download_url='https://github.com/zetaops/ulakbus/archive/master.zip',
    package_data={
        'ulakbus': ['diagrams/*.bpmn'],
    },
    keywords=['academic erp', 'universty automation system'],
    classifiers=[]
)



# -*- coding: utf-8 -*-

# Copyright (C) 2015 ZetaOps Inc.
#
# This file is licensed under the GNU General Public License v3
# (GPLv3).  See LICENSE.txt for details.


__author__ = 'Ali Riza Keles'

from zato.server.service import Service
import os
import httplib
import xml.etree.ElementTree as ET
import base64
import hashlib
import hmac
import datetime
import json
import uuid

DEBUG = os.environ.get('DEBUG', False)
if DEBUG:
    import logging

    httplib.HTTPConnection.debuglevel = 1
    logging.basicConfig()
    logging.getLogger().setLevel(logging.DEBUG)


class STSGetToken(Service):
    """
    NVI STS SSO Token
    """

    def handle(self):
        # tckn = self.request.payload['tckn']

        created = datetime.datetime.now().isoformat()
        expire = (datetime.datetime.now() + datetime.timedelta(minutes=10)).isoformat()
        username = os.environ["NVI_USER"]
        password = os.environ["NVI_PASS"]

        sts_request = """
            <s:Envelope xmlns:s="http://www.w3.org/2003/05/soap-envelope" xmlns:a="http://www.w3.org/2005/08/addressing" xmlns:u="http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-utility-1.0.xsd">
              <s:Header>
                <a:Action s:mustUnderstand="1">http://docs.oasis-open.org/ws-sx/ws-trust/200512/RST/Issue</a:Action>
                <a:MessageID>urn:uuid:%s</a:MessageID>
                <a:ReplyTo>
                  <a:Address>http://www.w3.org/2005/08/addressing/anonymous</a:Address>
                </a:ReplyTo>
                <a:To s:mustUnderstand="1">https://kimlikdogrulama.nvi.gov.tr/services/issuer.svc/IWSTrust13</a:To>
                <o:Security s:mustUnderstand="1" xmlns:o="http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd">
                  <u:Timestamp u:Id="_0">
                    <u:Created>%s</u:Created>
                    <u:Expires>%s</u:Expires>
                  </u:Timestamp>
                  <o:UsernameToken u:Id="uuid-a388cb10-46ab-48e5-9890-5103cc3dd20b-1">
                    <o:Username>%s</o:Username>
                    <o:Password Type="http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-username-token-profile-1.0#PasswordText">%s</o:Password>
                  </o:UsernameToken>
                </o:Security>
              </s:Header>
              <s:Body>
                <trust:RequestSecurityToken xmlns:trust="http://docs.oasis-open.org/ws-sx/ws-trust/200512">
                  <wsp:AppliesTo xmlns:wsp="http://schemas.xmlsoap.org/ws/2004/09/policy">
                    <a:EndpointReference>
                      <a:Address>https://kpsv2.nvi.gov.tr/services/RoutingService.svc</a:Address>
                    </a:EndpointReference>
                  </wsp:AppliesTo>
                  <trust:RequestType>http://docs.oasis-open.org/ws-sx/ws-trust/200512/Issue</trust:RequestType>
                </trust:RequestSecurityToken>
              </s:Body>
            </s:Envelope>
        """ % (str(uuid.uuid1()), str(created), str(expire), username, password)

        conn = httplib.HTTPConnection("services.konya.edu.tr", 3128)
        headers = {"Content-Type": "application/soap+xml; charset=utf-8"}
        conn.request("POST", "https://kimlikdogrulama.nvi.gov.tr/Services/Issuer.svc/IWSTrust13", sts_request, headers)

        response = conn.getresponse()
        sts_response = response.read()
        root = ET.fromstring(sts_response)
        created = datetime.datetime.now().isoformat()
        expire = (datetime.datetime.now() + datetime.timedelta(minutes=10)).isoformat()

        encrypted = root.find(
            '{http://www.w3.org/2003/05/soap-envelope}Body/{http://docs.oasis-open.org/ws-sx/ws-trust/200512}RequestSecurityTokenResponseCollection/{http://docs.oasis-open.org/ws-sx/ws-trust/200512}RequestSecurityTokenResponse/{http://docs.oasis-open.org/ws-sx/ws-trust/200512}RequestedSecurityToken/*')
        encrypted_data = ET.tostring(encrypted)

        key_identifier_path = root.find(
            '{http://www.w3.org/2003/05/soap-envelope}Body/{http://docs.oasis-open.org/ws-sx/ws-trust/200512}RequestSecurityTokenResponseCollection/{http://docs.oasis-open.org/ws-sx/ws-trust/200512}RequestSecurityTokenResponse/{http://docs.oasis-open.org/ws-sx/ws-trust/200512}RequestedUnattachedReference/{http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd}SecurityTokenReference/{http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd}KeyIdentifier').text

        binary_secret = root.find(
            '{http://www.w3.org/2003/05/soap-envelope}Body/{http://docs.oasis-open.org/ws-sx/ws-trust/200512}RequestSecurityTokenResponseCollection/{http://docs.oasis-open.org/ws-sx/ws-trust/200512}RequestSecurityTokenResponse/{http://docs.oasis-open.org/ws-sx/ws-trust/200512}RequestedProofToken/{http://docs.oasis-open.org/ws-sx/ws-trust/200512}BinarySecret').text

        digest_value = base64.b64encode(hashlib.sha1(
            '<u:Timestamp xmlns:u="http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-utility-1.0.xsd" u:Id="_0"><u:Created>' + created + '</u:Created><u:Expires>' + expire + '</u:Expires></u:Timestamp>').digest())

        signature = base64.b64encode(hmac.new(base64.b64decode(binary_secret),
                                              '<SignedInfo xmlns="http://www.w3.org/2000/09/xmldsig#"><CanonicalizationMethod Algorithm="http://www.w3.org/2001/10/xml-exc-c14n#"></CanonicalizationMethod><SignatureMethod Algorithm="http://www.w3.org/2000/09/xmldsig#hmac-sha1"></SignatureMethod><Reference URI="#_0"><Transforms><Transform Algorithm="http://www.w3.org/2001/10/xml-exc-c14n#"></Transform></Transforms><DigestMethod Algorithm="http://www.w3.org/2000/09/xmldsig#sha1"></DigestMethod><DigestValue>' + digest_value + '</DigestValue></Reference></SignedInfo>',
                                              hashlib.sha1).digest())

        result = {
            "nvi_sso_encrypted_data": encrypted_data,
            "nvi_sso_digest_value": digest_value,
            "nvi_sso_signature": signature,
            "nvi_sso_key_identifier_path": key_identifier_path,
            "nvi_sso_created": created,
            "nvi_sso_expire": expire
        }

        for k, v in result.iteritems():
            # save nvi sso data into redis for `3600` seconds
            self.kvdb.conn.set(k, v)
            self.kvdb.conn.expire(k, 600)

        if DEBUG:
            self.logger.info("NVI SSO invoked: %s" % json.dumps(result))

        self.response.payload = {"status": "ok", "result": json.dumps(result)}


# -*-  coding: utf-8 -*-
# Copyright (C) 2015 ZetaOps Inc.
#
# This file is licensed under the GNU General Public License v3
# (GPLv3).  See LICENSE.txt for details.
#
"""Akademik Takvim

Akademik Takvim İş Akışı modülü.

İş akışı tek adımdan oluşur. Bu adımda giriş yapan kullanıcının bağlı olduğu
birime ait akademik takvim gösterilir. Eğer birime özel bir akademik takvim bulunamazsa
üniversitenin genel takvimi görtüntülenir.

"""

from collections import OrderedDict


from pyoko.exceptions import ObjectDoesNotExist
from ulakbus.models.ogrenci import AKADEMIK_TAKVIM_ETKINLIKLERI
from ulakbus.models.ogrenci import AkademikTakvim, Unit
from zengine.views.crud import CrudView

__author__ = 'Ali Riza Keles'


class AkademikTakvimView(CrudView):
    """
    CrudView üzerine geliştirilmiştir.

    İş akışının tek adımına karşılık gelen tek bir metoda sahiptir.

    """

    class Meta:
        model = "AkademikTakvim"

    def goster(self):
        """
        AkademikTakvim modelinden kullanıcıya gösterilecek takvime erişir ve bir tablo
        halinde çıktıya ekler.

        Akademik Takvim öğelerinin (takvim etkinlikleri) sırlaması önemli olduğu için
        OrderedDict kullanılmıştır. Data bu sözlüğün içinde sıralandığı haliyle
        seriyalize edilir.

        AKADEMIK_TAKVIM_ETKINLIKLERI önceden tanımlanmış ve sıralanmış bir etkinlikler
        toplamıdır. AkademikTakvim modeli ile birlikte models.ogrenci modülü içinde
        sıralı olarak tanımlanmıştır. Örn::

            AKADEMIK_TAKVIM_ETKINLIKLERI = [
            ('1', 'Yeni Öğrenci Ön Kayıt'),
            ('2', 'Güz Dönem Başlangıcı'),
            ('3', 'Derslerin Acılması'),
            ('4', 'Subelendirme ve Ders Programının Ilan Edilmesi'),

            ...
            ('53', 'Yarıyıl Sınavı Not Giriş'),
            ('54', 'Yarıyıl Sınavı Notlarının Öğrenciye Yayınlanmasi'),
            ('55', 'Öğretim Elemanı Yoklama Girişi'),
            ]

        Kayıtların herbiri bu öğeler için belirli bir tarih veya tarih aralığına denk gelmektedir.

        """
        self.current.output['client_cmd'] = ['show', ]
        etkinlikler = []

        def get_akademik_takvim(unit):
            try:
                akademik_takvim = AkademikTakvim.objects.get(birim_id=unit.key)
                return akademik_takvim
            except ObjectDoesNotExist:
                yoksis_key = unit.parent_unit_no
                birim = Unit.objects.get(yoksis_no=yoksis_key)
                return get_akademik_takvim(birim)

        akademik_takvim = get_akademik_takvim(self.current.role.unit)
        for e in akademik_takvim.Takvim:
            etkinlik = OrderedDict({})
            etkinlik['Etkinlik'] = dict(AKADEMIK_TAKVIM_ETKINLIKLERI).get(str(e.etkinlik), '')
            etkinlik['Başlangıç'] = '{:%d.%m.%Y}'.format(e.baslangic)
            etkinlik['Bitiş'] = '{:%d.%m.%Y}'.format(e.bitis)
            etkinlikler.append(etkinlik)

        # cikti multirow table seklindedir.
        self.output['object'] = {
            "type": "table-multiRow",
            "fields": etkinlikler
        }


# -*-  coding: utf-8 -*-

# Copyright (C) 2015 ZetaOps Inc.
#
# This file is licensed under the GNU General Public License v3
# (GPLv3).  See LICENSE.txt for details.

"""Zato Servis URL Paths

Zato servislerine erişmek için kullanacağımız url pathlerden
oluşan sözlük.

"""

service_url_paths = {
    "HitapAcikSureGetir": {"url": "hizmet-acik-sure-getir"},
    "HitapAcikSureSenkronizeEt": {"url": "hizmet-acik-sure-sync"},
    "HitapAcikSureEkle": {"url": "hizmet-acik-sure-ekle"},
    "HitapAcikSureGuncelle": {"url": "hizmet-acik-sure-guncelle"},
    "HitapAcikSureSil": {"url": "hizmet-acik-sure-sil"},
    "HitapAskerlikGetir": {"url": "hizmet-askerlik-getir"},
    "HitapAskerlikSenkronizeEt": {"url": "hizmet-askerlik-sync"},
    "HitapAskerlikEkle": {"url": "hizmet-askerlik-ekle"},
    "HitapAskerlikGuncelle": {"url": "hizmet-askerlik-guncelle"},
    "HitapAskerlikSil": {"url": "hizmet-askerlik-sil"},
    "HitapBirlestirmeGetir": {"url": "hizmet-birlestirme-getir"},
    "HitapBirlestirmeSenkronizeEt": {"url": "hizmet-birlestirme-sync"},
    "HitapBirlestirmeEkle": {"url": "hizmet-birlestirme-ekle"},
    "HitapBirlestirmeGuncelle": {"url": "hizmet-birlestirme-guncelle"},
    "HitapBirlestirmeSil": {"url": "hizmet-birlestirme-sil"},
    "HitapBorclanmaGetir": {"url": "hizmet-borclanma-getir"},
    "HitapBorclanmaSenkronizeEt": {"url": "hizmet-borclanma-sync"},
    "HitapBorclanmaEkle": {"url": "hizmet-borclanma-ekle"},
    "HitapBorclanmaGuncelle": {"url": "hizmet-borclanma-guncelle"},
    "HitapBorclanmaSil": {"url": "hizmet-borclanma-sil"},
    "HitapHizmetCetveliGetir": {"url": "hizmet-cetveli-getir"},
    "HitapHizmetCetveliSenkronizeEt": {"url": "hizmet-cetveli-sync"},
    "HitapHizmetCetveliEkle": {"url": "hizmet-cetveli-ekle"},
    "HitapHizmetCetveliGuncelle": {"url": "hizmet-cetveli-guncelle"},
    "HitapHizmetCetveliSil": {"url": "hizmet-cetveli-sil"},
    "HitapIHSGetir": {"url": "hizmet-ihs-getir"},
    "HitapIHSSenkronizeEt": {"url": "hizmet-ihs-sync"},
    "HitapIHSEkle": {"url": "hizmet-ihs-ekle"},
    "HitapIHSGuncelle": {"url": "hizmet-ihs-guncelle"},
    "HitapIHSSil": {"url": "hizmet-ihs-sil"},
    "HitapIstisnaiIlgiGetir": {"url": "hizmet-istisnai-ilgi-getir"},
    "HitapIstisnaiIlgiSenkronizeEt": {"url": "hizmet-istisnai-ilgi-sync"},
    "HitapIstisnaiIlgiEkle": {"url": "hizmet-istisnai-ilgi-ekle"},
    "HitapIstisnaiIlgiGuncelle": {"url": "hizmet-istisnai-ilgi-guncelle"},
    "HitapIstisnaiIlgiSil": {"url": "hizmet-istisnai-ilgi-sil"},
    "HitapKursGetir": {"url": "hizmet-kurs-getir"},
    "HitapKursSenkronizeEt": {"url": "hizmet-kurs-sync"},
    "HitapKursEkle": {"url": "hizmet-kurs-ekle"},
    "HitapKursGuncelle": {"url": "hizmet-kurs-guncelle"},
    "HitapKursSil": {"url": "hizmet-kurs-sil"},
    "HitapMahkemeGetir": {"url": "hizmet-mahkeme-getir"},
    "HitapMahkemeSenkronizeEt": {"url": "hizmet-mahkeme-sync"},
    "HitapMahkemeEkle": {"url": "hizmet-mahkeme-ekle"},
    "HitapMahkemeGuncelle": {"url": "hizmet-mahkeme-guncelle"},
    "HitapMahkemeSil": {"url": "hizmet-mahkeme-sil"},
    "HitapNufusGetir": {"url": "hizmet-nufus-getir"},
    "HitapNufusSenkronizeEt": {"url": "hizmet-nufus-sync"},
    "HitapNufusEkle": {"url": "hizmet-nufus-ekle"},
    "HitapNufusGuncelle": {"url": "hizmet-nufus-guncelle"},
    "HitapNufusSil": {"url": "hizmet-nufus-sil"},
    "HitapOkulGetir": {"url": "hizmet-okul-getir"},
    "HitapOkulSenkronizeEt": {"url": "hizmet-okul-sync"},
    "HitapOkulEkle": {"url": "hizmet-okul-ekle"},
    "HitapOkulGuncelle": {"url": "hizmet-okul-guncelle"},
    "HitapOkulSil": {"url": "hizmet-okul-sil"},
    "HitapTazminatGetir": {"url": "hizmet-tazminat-getir"},
    "HitapTazminatSenkronizeEt": {"url": "hizmet-tazminat-sync"},
    "HitapTazminatEkle": {"url": "hizmet-tazminat-ekle"},
    "HitapTazminatGuncelle": {"url": "hizmet-tazminat-guncelle"},
    "HitapTazminatSil": {"url": "hizmet-tazminat-sil"},
    "HitapUnvanGetir": {"url": "hizmet-unvan-getir"},
    "HitapUnvanSenkronizeEt": {"url": "hizmet-unvan-sync"},
    "HitapUnvanEkle": {"url": "hizmet-unvan-ekle"},
    "HitapUnvanGuncelle": {"url": "hizmet-unvan-guncelle"},
    "HitapUnvanSil": {"url": "hizmet-unvan-sil"},
    "MernisKimlikBilgileriGetir": {"url": "nvi-kisi-sorgula"},
    "MernisCuzdanBilgileriGetir": {"url": "nvi-cuzdan-sorgula"},
    "KPSAdresBilgileriGetir": {"url": "nvi-adres-sorgula"}
}



# -*-  coding: utf-8 -*-
"""
"""

# Copyright (C) 2015 ZetaOps Inc.
#
# This file is licensed under the GNU General Public License v3
# (GPLv3).  See LICENSE.txt for details.
from collections import OrderedDict

from pyoko.exceptions import ObjectDoesNotExist

from pyoko import ListNode
from ulakbus.models import Sube, OgrenciDersi, DersKatilimi

from zengine.forms import fields
from ulakbus.lib.view_helpers import prepare_choices_for_model

from zengine import forms
from zengine.views.crud import CrudView

__author__ = 'Ali Riza Keles'


class DevamsizlikForm(forms.JsonForm):
    class Meta:
        inline_edit = ['katilim_durumu', 'aciklama']

    class Ogrenciler(ListNode):
        ogrenci_no = fields.String('No')
        ad_soyad = fields.String('Ad Soyad')
        katilim_durumu = fields.Integer('Katılım Durumu')
        aciklama = fields.String('Açıklama')
        ogrenci_key = fields.String('ogrenci_key', hidden=True)
        ders_key = fields.String('ders_key', hidden=True)


class KatilimDurumu(CrudView):
    """Okutman Not Girişi

    Okutmanların öğrenci devamsızlıklarını sisteme girebilmesini
    sağlayan workflowa ait metdodları barındıran sınıftır.

    """

    class Meta:
        model = "DersKatilimi"

    def sube_sec(self):
        """Sube seçim adımına karşılık gelen metod."""
        _form = forms.JsonForm(current=self.current, title="Ders Seçim Formu")
        _form.sube = fields.Integer("Sube Seçiniz",
                                    choices=prepare_choices_for_model(Sube,
                                                                      okutman_id=self.get_okutman_key))
        _form.sec = fields.Button("Seç", cmd="Ders Şubesi Seçin")
        self.form_out(_form)

    def katilim_durumu(self):
        """Öğrencileri listesinden bir form oluşturur. Yerinde düzenleme
        ile öğrenci devamsızlıkları girilir."""

        _form = DevamsizlikForm(current=self.current, title="Ders Katılımı Giriş Formu")

        try:
            sube_key = self.current.input['form']['sube']
            self.current.task_data["sube_key"] = sube_key
        except KeyError:
            sube_key = self.current.task_data["sube_key"]

        ogrenciler = OgrenciDersi.objects.filter(sube_id=sube_key)

        for ogr in ogrenciler:
            try:
                katilim = DersKatilimi.objects.get(ders_id=sube_key, ogrenci=ogr.ogrenci)
                katilim_durumu = katilim.katilim_durumu
            except ObjectDoesNotExist:
                katilim_durumu = ""

            _form.Ogrenciler(ad_soyad='%s %s' % (ogr.ogrenci.ad, ogr.ogrenci.soyad),
                             ogrenci_no=ogr.ogrenci_program.ogrenci_no,
                             katilim_durumu=katilim_durumu, ogrenci_key=ogr.ogrenci.key,
                             ders_key=ogr.sube.key)

        _form.kaydet = fields.Button("Önizleme", cmd="kontrol")
        self.form_out(_form)
        self.current.output["meta"]["allow_actions"] = False

    def kontrol(self):
        """Önceki adımda forma girilen bilgilerin doğruluğunun
        kontrol edilmesi için bilgileri bir tablo şeklinde ekrana
        getirir."""

        ogrenci_katilim_durumlari = self.current.input['form']['Ogrenciler']
        self.current.task_data["katilim_durumlari"] = ogrenci_katilim_durumlari

        katilim_durumlari = []
        for ogr in ogrenci_katilim_durumlari:
            katilim_durumu = OrderedDict({})
            katilim_durumu['Öğrenci No'] = ogr['ogrenci_no']
            katilim_durumu['Adı Soyadı'] = ogr['ad_soyad']
            katilim_durumu['Değerlendirme'] = ogr['katilim_durumu']
            katilim_durumu['ogrenci_key'] = ogr['ogrenci_key']
            katilim_durumu['ders_key'] = ogr['ders_key']
            katilim_durumlari.append(katilim_durumu)

        _form = forms.JsonForm(current=self.current,
                               title="Katılım Durumu Bilgileri Önizleme Ekranı")
        _form.duzenle = fields.Button("Geri Dön ve Düzenle", cmd="katilim_durumu",
                                      flow="katilim_durumu")
        _form.kaydet = fields.Button("Kaydet", cmd="kaydet", flow="end")

        self.current.output['object'] = {
            "type": "table-multiRow",
            "fields": katilim_durumlari,
            "actions": False
        }

        self.form_out(_form)

    def kaydet(self):
        """Doğruluğu onaylanan bilgileri kaydeder."""
        for katilim in self.current.task_data['katilim_durumlari']:
            ders_katilimi, is_new = DersKatilimi.objects.get_or_create(
                ogrenci_id=katilim['ogrenci_key'], ders_id=katilim['ders_key'])
            ders_katilimi.katilim_durumu = katilim['katilim_durumu']
            ders_katilimi.save()

    def bilgi_ver(self):
        """Yapılan işlem hakkında bilgi verir."""
        sube = Sube.objects.get(self.current.task_data['sube_key'])

        self.current.output['msgbox'] = {
            'type': 'info', "title": 'Devamsızlıklar Kaydedildi',
            "msg": '%s dersine ait ogrenci katilim bilgileri  kaydedildi' % sube.ders.ad}

    @property
    def get_okutman_key(self):
        """Harici okutman ve okutman kayıt key'lerinin ayrımını sağlayan method.
        """
        return self.current.user.personel.okutman.key if self.current.user.personel.key else self.current.user.harici_okutman.okutman.key



# -*-  coding: utf-8 -*-
"""
"""

# Copyright (C) 2015 ZetaOps Inc.
#
# This file is licensed under the GNU General Public License v3
# (GPLv3).  See LICENSE.txt for details.

"""HITAP IHS Guncelle

Hitap'a personelin IHS bilgilerinin guncellemesini yapar.

"""

__author__ = 'H.İbrahim Yılmaz (drlinux)'

from ulakbus.services.personel.hitap.hitap_guncelle import HITAPGuncelle
# todo: from ulakbus.models.hitap.hitap import HizmetIHS


class HizmetIhsGuncelle(HITAPGuncelle):
    """
    HITAP Ekleme servisinden kalıtılmış Hizmet IHS Bilgisi Guncelleme servisi

    """

    def handle(self):
        """Servis çağrıldığında tetiklenen metod.

        Attributes:
            service_name (str): İlgili Hitap sorgu servisinin adı
            service_dict (dict): ''HizmetIHS'' modelinden gelen kayıtların alanları,
                    HizmetIHSUpdate servisinin alanlarıyla eşlenmektedir.
                    Filtreden geçecek tarih alanları listede tutulmaktadır.

        """

        self.service_name = 'HizmetIHSUpdate'
        self.service_dict = {
            'fields': {
                'ihzID': self.request.payload.get('kayit_no', ''),
                'tckn': self.request.payload.get('tckn', ''),
                'baslamaTarihi': self.request.payload.get('baslama_tarihi', ''),
                'bitisTarihi': self.request.payload.get('bitis_tarihi', ''),
                'ihzNevi': self.request.payload.get('ihz_nevi', '')
            },
            'date_filter': ['baslamaTarihi', 'bitisTarihi'],
            'required_fields': ['tckn', 'ihzID', 'baslamaTarihi', 'bitisTarihi', 'ihzNevi']
        }
        super(HizmetIhsGuncelle, self).handle()



# -*-  coding: utf-8 -*-
"""
"""

# Copyright (C) 2015 ZetaOps Inc.
#
# This file is licensed under the GNU General Public License v3
# (GPLv3).  See LICENSE.txt for details.

"""HITAP Tazminat Ekle

Hitap'a personelin Tazminat bilgilerinin eklenmesini yapar.

"""

__author__ = 'H.İbrahim Yılmaz (drlinux)'

from ulakbus.services.personel.hitap.hitap_ekle import HITAPEkle


class HizmetTazminatEkle(HITAPEkle):
    """
    HITAP Ekleme servisinden kalıtılmış Hizmet Tazminat Bilgi Ekleme servisi

    """

    def handle(self):
        """Servis çağrıldığında tetiklenen metod.

        Attributes:
            service_name (str): İlgili Hitap sorgu servisinin adı
            service_dict (dict): Request yoluyla gelen kayıtların alanları,
                    HizmetTazminatInsert servisinin alanlarıyla eşlenmektedir.
                    Filtreden geçecek tarih alanları ve servis tarafında gerekli olan
                    alanlar listede tutulmaktadır.

        """
        self.service_name = 'HizmetTazminatInsert'
        self.service_dict = {
            'fields': {
                'gorev': self.request.payload.get('gorev', ''),
                'kadrosuzluk': self.request.payload.get('kadrosuzluk', ''),
                'makam': self.request.payload.get('makam', ''),
                'tckn': self.request.payload.get('tckn', ''),
                'temsil': self.request.payload.get('temsil', ''),
                'unvanKod': self.request.payload.get('unvan_kod', ''),
                'tazminatTarihi': self.request.payload.get('tazminat_tarihi', ''),
                'tazminatBitisTarihi': self.request.payload.get('tazminat_bitis_tarihi', ''),
                'kurumOnayTarihi': self.request.payload.get('kurum_onay_tarihi', '')
            },
            'date_filter': ['tazminatTarihi', 'tazminatBitisTarihi', 'kurumOnayTarihi'],
            'required_fields': ['tckn', 'unvanKod', 'tazminatTarihi', 'kurumOnayTarihi']
        }
        super(HizmetTazminatEkle, self).handle()
